
clear
set mem 5g
set more 1

capture log using "exchange rate correlations.log", replace


use xr_annual
keep year cty_code cty_name dxr
drop if year<2000|year>2008
gen x=1 if dxr~=.
egen sumx=sum(x), by(cty_code)
tab cty_name if sumx<9
drop if sumx<9
drop sumx x
save temp, replace



local ctycorr "AU CA CH GB IL IS JP KR NO NZ SE US"

foreach corr of local ctycorr{
	use temp

	*Generating destination country XR variable for correlation
	g temp`corr'dxr=dxr if cty_code=="`corr'" 
	bys year: egen `corr'dxr=max(temp`corr'dxr) //spreading year specific destination XR data to all countries
	drop temp`corr'dxr
	
	levelsof cty_code, local(ctys) //local with all countries containing dxr data for all years 
	g `corr'corr=.

	*Getting correlations
	foreach cty of local ctys{
		corr dxr `corr'dxr if cty_code=="`cty'"
		replace `corr'corr=r(rho) if cty_code=="`cty'"
	}
	
	*cleaning and saving
	keep cty_code cty_code cty_name cty_name `corr'corr
	drop if `corr'corr==.
	gen peg="`corr'"
	duplicates drop
	rename `corr'corr corr
	sort peg cty_code 
	
	save peg_`corr', replace
}


local ctycorr2 "AU CA CH GB IL IS JP KR NO NZ SE"

foreach corr2 of local ctycorr2{

append using peg_`corr2'

}

label var peg "destination country that corr refers to"
save allpegs, replace


*CALCULATE HIGH CORR PHI AND LOW CORR PHI
******************************************************************

*i. only keep exporters and drop euro imports
use exports_allyears_annual
keep vat
duplicates drop
sort vat
save vat_exporters, replace

use imports_allyears_annual
drop if year<2000|year>2008
*only keep exporters
*10% of imports do not export
sort vat
merge vat using vat_exporters
tab _merge
keep if _merge==3
drop _merge
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2

*drop euroimports
drop if euro_dum==1
drop euro_dum _merge
sort cty_code
save imports_temp, replace


*ii. choose correlation cutoff: 0.7
use allpegs
keep if corr>0.7 
keep cty_code peg
sort cty_code
save allpegs_high, replace



local ctycorr "AU CA CH GB IL IS JP KR NO NZ SE US"

foreach corr of local ctycorr{
use allpegs_high
keep if peg=="`corr'"
sort cty_code
save peg_`corr', replace

use imports_temp
merge cty_code using peg_`corr'
gen hc=1 if _merge==3
replace hc=0 if hc==.
collapse (sum) value, by(vat year hc)
reshape wide value, i(year vat) j(hc)
replace value0=0 if value0==.
replace value1=0 if value1==.
gen noneuroimports=value0+value1
gen lcimports=value0
gen hcimports=value1
sort vat year
merge vat year using mc_firm
drop if year>2008
tab _merge
drop if _merge==2
drop _merge
gen overpeg=1 if noneuroimports>matcost
gen phi_hc=hcimports/totcost
gen phi_lc=lcimports/totcost
replace phi_hc=0 if hcimports/totcost==.
replace phi_lc=0 if lcimports/totcost==.
replace phi_hc=. if overpeg==1
replace phi_lc=. if overpeg==1

keep year vat phi_hc phi_lc
gen cty_code="`corr'"
sort vat year cty_code
save phi_hc_`corr', replace

}

local ctycorr2 "AU CA CH GB IL IS JP KR NO NZ SE"

foreach corr2 of local ctycorr2{

append using phi_hc_`corr2'

}

sort vat cty_code year
save phi_hc,replace


local ctycorr "AU CA CH GB IL IS JP KR NO NZ SE US"

foreach corr of local ctycorr{
	erase peg_`corr'.dta
	erase phi_hc_`corr'.dta
	
	}




log close
