
clear
set mem 5g
set more 1

capture log using "AERrev high passthrough.log", replace

************************************************
*organize import data to construct phi
*we will use imports_temp to construct the phi
*we use temp to estimate import pass through to rank countries
*********************************************************
*only keep exporters and drop euro imports
use exports_allyears_annual
keep vat
duplicates drop
sort vat
save vat_exporters, replace

use imports_allyears_annual
drop if year<2000|year>2008
*only keep exporters
*10% of imports do not export
sort vat
merge vat using vat_exporters
tab _merge
keep if _merge==3
drop _merge
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2

*drop euroimports
drop if euro_dum==1
drop euro_dum _merge
sort cty_code
save imports_temp, replace


******************************************
*calculate pass through int0 imports
******************************************
use imports_allyears_annual
*only keep manuf firms
sort vat
merge vat using nace2_manuf
keep if _merge==3
drop _merge
sort vat
merge vat using vat_exporters
keep if _merge==3
drop _merge

*merge in exchange rates and drop euro countries
*set years and merge in data with euro dummy
sort cty_code year
merge cty_code year using xr_annual
tab _merge
keep if _merge==3
drop _merge
drop if year<1999
drop if year>2008

rename dxr dem

*create euro dummies
egen euro=mean(euro_dum), by(cty_code)
replace euro=0 if euro==.
drop if euro==1

egen fpd=group(vat code cty_code)
duplicates tag fpd year, gen(tag)
keep if tag==0
drop tag

tsset fpd year
*checking for units consistency
gen uv1=value/weight
gen uv2=value/units
gen duv1=ln(uv1/l.uv1)
gen duv2=ln(uv2/l.uv2)
gen duv=duv1
replace duv=duv2 if duv==.
gen pratio1=uv1/l.uv1
gen pratio2=uv2/l.uv2
gen pratio=pratio1
replace pratio=pratio2 if pratio==.

gen cleanr=1 if pratio>3 & pratio~=.
replace cleanr=1 if pratio<1/3

rename duv dpm

drop if cleanr==1
drop if dpm==.
drop if dem==.
sort vat
egen nobs=count(vat), by(cty_code)
save temp, replace


************************************
*import exchange rate pass-through by oecd-nonoecd
******************************************
use temp, clear
drop if nobs<50
sort cty_code
merge cty_code using noneuro_oecd
tab _merge
keep if _merge==3
drop _merge

egen ky=group(cty_code year)
gen dem_oecd=dem*noneuro_oecd
gen dem_noecd=dem*(1-noneuro_oecd)

*unweighted
reg dpm dem_oecd dem_noecd noneuro_oecd, cluster(ky)
test dem_oecd = dem_noecd


*weighted
reg dpm dem_oecd dem_noecd noneuro_oecd [w=value], cluster(ky)
test dem_oecd = dem_noecd
clear


************************************
*import exchange rate pass-through
******************************************
use temp, clear
drop if nobs<50

levelsof cty_code, local(country)
gen beta=.
gen se=.
foreach c of local country{
	reg dpm dem if cty_code=="`c'" 
	noisily capture reg dpm dem if cty_code=="`c'" 
	noisily capture replace beta=_b[dem] if cty_code=="`c'"
	noisily capture replace se=_se[dem] if cty_code=="`c'"
}

egen totcountry=sum(value), by(cty_code)
egen totvalue=sum(value)
gen sh=totcountry/totvalue

keep cty_code cty_name sh nobs beta se
duplicates drop
sort cty_code
save import_pt, replace


use import_pt
gen hpt=.
replace hpt=1 if inlist(cty_code, "MO", "PE", "UG", "AE", "CL", "TW", "CA", "AU", "SA")
replace hpt=1 if inlist(cty_code, "CN", "US", "RU", "HK", "GT", "JP", "CO", "CH", "MX")
replace hpt=1 if inlist(cty_code, "BD") 
replace hpt=2 if inlist(cty_code, "ZM", "PY", "IL", "IN", "BR", "TH", "LK", "MY", "EG")
replace hpt=2 if inlist(cty_code, "PH", "VE", "SG", "SE", "HN", "UY", "DO", "MG", "ET")
replace hpt=2 if inlist(cty_code, "KR", "GB", "ID", "UA", "NZ", "GH", "AR", "BY", "CD")
replace hpt=2 if inlist(cty_code, "TR", "ZW", "PK", "VN", "ZA") 

sort cty_code
save rimport_pt, replace

****************************************
*construct high pt phi
**************************************

*only keeps imports from countries for which we have a pt coefficient in construction of phi
use imports_temp
merge cty_code using rimport_pt
drop if _merge==2
drop _merge
replace hpt=0 if hpt==.
collapse (sum) value, by(vat year hpt)
reshape wide value, i(year vat) j(hpt)
replace value0=0 if value0==.
replace value1=0 if value1==.
replace value2=0 if value2==.
gen noneuroimports=value0+value1+value2
gen hptimports=value1
gen lptimports=value2
gen optimports=value0
sort vat year
merge vat year using mc_firm
drop if year>2008
tab _merge
drop if _merge==2
drop _merge
gen overpeg=1 if noneuroimports>matcost
gen phi_hpt=hptimports/totcost
gen phi_lpt=lptimports/totcost
gen phi_opt=optimports/totcost
replace phi_hpt=0 if hptimports/totcost==.
replace phi_lpt=0 if lptimports/totcost==.
replace phi_opt=0 if optimports/totcost==.
keep year vat phi_hpt phi_lpt phi_opt
sort vat year 
save phi_hpt, replace

log close











	
	