set more 1
clear

set mem 3g


*****************************
capture log using "AERrev tables alt phi.log", replace


use estdata_sample_rev
sort vat year
merge vat year using ../data/man_impshare
drop if _merge==2
drop _merge
keep vat cty_code year man_tc nonman_tc phi*
duplicates drop
replace man_tc=0 if phi==0
replace nonman_tc=0 if phi==0
collapse (mean) mphi_man=man_tc mphi_nonman=nonman_tc, by(vat)
sort vat 
save mphi_man, replace


use ../data/estdata_oecd_rev
tsset fpd year
egen fpy=group(vat code year)
egen hs4d=group(hs4 cty_code)
egen ky=group(cty_code year)
egen py=group(code year)
egen fy=group(vat year)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)

*want to make sure sample size is same in all regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if major_io==1
keep if manuf==1

sort vat year
merge vat year using ../data/lagphi
drop if _merge==2
drop _merge

sort vat
merge vat using mphi_man
drop if _merge==2
drop _merge
save temp, replace

*construct mean phi
keep vat year phi* noneuroimp_tc_cap
duplicates drop
drop phiB
collapse (mean) mphi=phi mphi_bec=phi_bec mphi_cap=noneuroimp_tc_cap mphi_io=phi_io mphi_io2=phi_io2 mphi_io3=phi_io3 , by(vat)
sort vat
save mphi_1, replace


use temp
sort vat
merge vat using mphi_1
drop if _merge==2
drop _merge

gen mphi_dei=mphi*dei
gen mphi_bec_dei=mphi_bec*dei
gen mphi_io_dei=mphi_io*dei
gen mphi_io2_dei=mphi_io2*dei
gen mphi_io3_dei=mphi_io3*dei



***********************************
*Estimation
*********************************************
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei


*lag phi and lag mktsh
gen lagmktsh_dei=lagmktsh*dei
gen lagphi_dei=lagphi*dei

*alternative measures of phi
*1. time varying phi (but in lags)
drop mphi_dei mphi
gen mphi=lagphi
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi lagmktsh_dei lagmktsh yr*, cluster(ky) absorb(hs4d)

*2 drop manuf
drop mphi_dei mphi
gen mphi=mphi_man
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)

*3. mphi_bec
drop mphi_dei mphi
gen mphi=mphi_bec
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)

*4. mphi_cap
drop mphi_dei mphi
gen mphi=mphi_cap
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)

*5. mphi_io
drop mphi_dei mphi
gen mphi=mphi_io
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)


*6. mphi_io3
drop mphi_dei mphi
gen mphi=mphi_io3
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)


*7. mphi_io2
drop mphi_dei mphi
gen mphi=mphi_io2
gen mphi_dei=mphi*dei
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)



esttab using "AERrev_tables_altphi.csv", se keep(dei mphi_dei mphi mktsh_dei mktsh lagmktsh_dei lagmktsh ) b(3) se(3) r2 ar2 star(* 0.10 ** 0.05 *** 0.01) order(dei mphi_dei mphi mktsh_dei mktsh lagmktsh_dei lagmktsh ) compress replace
eststo clear

log close
