set more 1
clear

set mem 12g


*****************************
capture log using "AERrev tables alt samples.log", replace

*all countries
*******************************
use ../data/estdata_allcountries_rev
drop if cty_code==""
collapse (sum) value, by(cty_code year)
egen totvalue=sum(value), by(year)
gen share=value/totvalue
collapse (mean) share, by(cty_code)
sort cty_code
save allcountries_share, replace

use ../data/estdata_allcountries_rev
drop if cty_code==""
sort cty_code
merge cty_code using allcountries_share
tab _merge
drop if _merge==2
drop _merge

*choose cutoff
drop if share<0.001

*prepare dummies and choose sample
************************

/*do this after dropping wholesalers and increase it to 100 at least
gen cc=1
egen sumcc=sum(cc), by(cty_name)
drop if sumcc<20
*/

tsset fpd year
egen fpy=group(vat code year)
egen hs4d=group(hs4 cty_code)
egen ky=group(cty_code year)
egen py=group(code year)
egen fy=group(vat year)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)

*want to make sure sample size is same in all regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if major_io==1
keep if manuf==1


sort vat
merge vat using mphi

drop if _merge==2
drop _merge
gen mphi_dei=mphi*dei


***********************************
*Estimation
*********************************************

*choose which market share variable to use
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei

*col 1 - all noneuro countries
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, robust cluster(ky) absorb(hs4d)

keep cty_code
duplicates drop
count

drop _all
********************************


use ../data/estdata_oecd_rev
*prepare dummies and choose sample
************************
tsset fpd year
egen fpy=group(vat code year)
egen hs4d=group(hs4 cty_code)
egen ky=group(cty_code year)
egen py=group(code year)
egen fy=group(vat year)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)

*want to make sure sample size is same in all regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if major_io==1
keep if manuf==1

sort vat
merge vat using mphi

drop if _merge==2
drop _merge
gen mphi_dei=mphi*dei



***********************************
*Estimation
*********************************************

*choose which market share variable to use
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei

*col2: without US
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr* if cty_code~="US", robust cluster(ky) absorb(hs4d)

*col3: only US
eststo: areg dpi mphi_dei mphi mktsh_dei mktsh yr* if cty_code=="US", robust absorb(hs4)
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh if cty_code=="US", robust absorb(hs4)


*********************************************************************************
drop _all
*with wholesalers
use ../data/estdata_oecd_rev
*prepare dummies and choose sample
************************
tsset fpd year
egen fpy=group(vat code year)
egen hs4d=group(hs4 cty_code)
egen ky=group(cty_code year)
egen py=group(code year)
egen fy=group(vat year)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)

*want to make sure sample size is same in all  regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if major_io==1

*construct mean phi
preserve
keep vat year phi
duplicates drop
collapse (mean) mphi=phi, by(vat)
sort vat
save mphi_w, replace

restore
sort vat
merge vat using mphi_w

drop if _merge==2
drop _merge
gen mphi_dei=mphi*dei

gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei

*col 4 - wholesalers
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, robust cluster(ky) absorb(hs4d)
drop _all

***************************************************8
*drop intra-firm trade
*********************************
clear
***************************************************************
*mne
use ../rawdata/mne_out
drop if year>2008
gen fdi_outs=fa_sales>0 & fa_sales~=.
rename mne fdi_out
keep vat year cty_code fdi*
label var fdi_out "outward fdi dummy destination-sepcific"
label var fdi_outs "intra-firm sales"
drop if vat==.

sort vat year cty_code
save mne, replace

use ../rawdata/mne_in
drop if year>2008
gen fdi_ins=fs_sales>0 & fs_sales~=.
rename for fdi_in
keep vat year cty_code fdi*
label var fdi_in "inward fdi dummy destination-specific"
label var fdi_ins "intra-firm sales"
sort vat year cty_code
save for, replace

*create time-invarying destination-specific
use mne
sort vat year cty_code
merge vat year cty_code using for
keep vat cty_code
duplicates drop
gen fdi_k=1
sort vat cty_code
save fdi_k, replace



********************************************
use estdata_sample_rev, replace
sort vat cty_code
merge vat cty_code using fdi_k
tab _merge
drop if _merge==2
replace fdi_k=0 if fdi_k==.
tab fdi_k


***********************************
*Estimation
*********************************************

*choose which market share variable to use
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei

*fdi_k is dummy=1 at firm-destination level if any inward or outward fdi in that country

*col5 - droppping intra-firm trade
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr* if fdi_k==0, robust cluster(ky) absorb(hs4d)


drop _all

*********************************************************
*alt major
use ../data/estdata_oecd_rev
************************
tsset fpd year
egen fpy=group(vat code year)
egen hs4d=group(hs4 cty_code)
egen ky=group(cty_code year)
egen py=group(code year)
egen fy=group(vat year)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)

*want to make sure sample size is same in all regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if manuf==1

sort vat
merge vat using mphi

drop if _merge==2
drop _merge
gen mphi_dei=mphi*dei

gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei


*col6 - all products
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, robust cluster(ky) absorb(hs4d)

*col7- hs4
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr* if major_hs4==1, robust cluster(ky) absorb(hs4d)

*col 8 - hs4 and share>0.5
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr* if major_hs4==1 & hs4share>0.5, robust cluster(ky) absorb(hs4d)



esttab using "AERrev_tables_altsamples.csv", se keep(dei mphi_dei mphi mktsh_dei mktsh ) b(3) se(3) r2 ar2 star(* 0.10 ** 0.05 *** 0.01) order(dei mphi_dei mphi mktsh_dei mktsh ) compress replace
eststo clear



log close
