set more 1
clear

set mem 3g


*****************************
capture log using "AERrev tables baseline.log", replace
use ../data/estdata_oecd_rev
************************

tsset fpd year
egen fpy=group(vat code year)
egen py=group(code year)
egen fy=group(vat year)
egen ky=group(cty_code year)
egen hs4dy=group(hs4 cty_code year)
egen hs4d=group(hs4 cty_code)
quietly tab cty_code, gen(cdum) 
quietly tab year, gen(yr)


*want to make sure sample size is same in all regressions
gen all=1
replace all=. if dpi==.
replace all=. if dei==.
replace all=. if dmc==.
keep if all==1
keep if major_io==1
keep if manuf==1


*construct mean phi
preserve
keep vat year phi
duplicates drop
collapse (mean) mphi=phi, by(vat)
sort vat
save mphi, replace

restore
sort vat
merge vat using mphi

drop if _merge==2
drop _merge
gen mphi_dei=mphi*dei

save estdata_sample_rev, replace



***********************************
*Estimation
*********************************************
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei

eststo: areg dpi dei yr*, robust cluster(ky) absorb(hs4d)
eststo: areg dpi dei mphi_dei mphi yr*, robust cluster(ky) absorb(hs4d)
eststo: areg dpi dei mphi_dei dmc mphi yr*, robust cluster(ky) absorb(hs4d)
eststo: areg dpi dei mphi_dei cdum*, robust cluster(ky) absorb(fpy)
eststo: areg dpi dei mphi_dei dmc mphi mktsh_dei mktsh yr*, robust cluster(ky) absorb(hs4d)
eststo: areg dpi dei mphi_dei mphi mktsh_dei mktsh yr*, robust cluster(ky) absorb(hs4d)
eststo: areg dpi mphi_dei mphi mktsh_dei mktsh, robust absorb(hs4dy)

esttab using "AERrev_tables_baseline.csv", se keep(dei mphi_dei mphi dmc mktsh_dei mktsh ) b(3) se(3) r2 ar2 star(* 0.10 ** 0.05 *** 0.01) order(dei mphi_dei mphi dmc mktsh_dei mktsh ) compress replace
eststo clear


************************************
*by mean phi bins
***********************************************
xtile split_e=mphi, nq(4)
quietly tab split, gen(q)


forvalues i=1/4 {
gen q`i'_dei=q`i'*dei
}


tabstat mphi, by(split) stat(mean min max n)


*phi interactions by quartile
reg dpi q* yr*, robust cluster(ky) 
reg dpi q* dmc yr*, robust cluster(ky)  
reg dpi q* dmc mktsh_dei mktsh yr*, robust cluster(ky) 
reg dmc q* yr*, robust cluster(ky) 


*relative regressions
drop q1*
reg dpi dei q* yr*, robust cluster(ky) 
reg dpi dei q* dmc yr*, robust cluster(ky) 
reg dpi dei q* dmc mktsh_dei mktsh yr*, robust cluster(ky) 
reg dmc dei q* yr*, robust cluster(ky) 


*sum stats for mktshare and mphi
sum mphi, detail

egen avmktsh=mean(mktsh), by(vat)
sum avmktsh, detail

log close


