set more 1
clear

set mem 5g


*****************************
capture log using "AERrev tables import source.log", replace

use estdata_sample_rev
sort vat cty_code year
merge vat cty_code year using ../data/phi_hc
drop if _merge==2
drop _merge
keep vat cty_code year phi*
duplicates drop
replace phi_hc=0 if phi==0
replace phi_lc=0 if phi==0
collapse (mean) mphi_hc=phi_hc mphi_lc=phi_lc, by(vat cty_code)
sort vat cty_code
save mphi_hc, replace

use estdata_sample_rev
sort vat year
merge vat year using ../data/phi_hpt
drop if _merge==2
drop _merge
keep vat year phi* 
duplicates drop
replace phi_hpt=0 if phi==0
replace phi_lpt=0 if phi==0
replace phi_opt=0 if phi==0
gen phi_lopt=phi_lpt+phi_opt
collapse (mean) mphi_hpt=phi_hpt mphi_lpt=phi_lpt mphi_opt=phi_opt mphi_lopt=phi_lopt , by(vat)
duplicates drop
sort vat
save mphi_hpt, replace

use estdata_sample_rev
keep vat year phi* noneuroimp_tc oecd_tc nonoecd_tc euroimp_tc
duplicates drop
collapse (mean) meuroimp_tc=euroimp_tc moecd_tc=oecd_tc mnonoecd_tc=nonoecd_tc, by(vat)
duplicates drop
sort vat
save mphi_3, replace

use estdata_sample_rev
sort vat cty_code
merge vat cty_code using mphi_hc
drop if _merge==2
drop _merge
sort vat
merge vat using mphi_hpt
drop if _merge==2
drop _merge
sort vat
merge vat using mphi_3
drop if _merge==2
drop _merge


***********************************
*Estimation
*********************************************

*choose which market share variable to use
gen mktsh=mshareB_hs4d
gen mktsh_dei=mktsh*dei


*prepare variables
gen moecd_tc_dei=moecd_tc*dei
gen mnonoecd_tc_dei=mnonoecd_tc*dei
gen meuroimp_tc_dei=meuroimp_tc*dei
gen mphi_hc_dei=mphi_hc*dei
gen mphi_lc_dei=mphi_lc*dei
gen mphi_hpt_dei=mphi_hpt*dei
gen mphi_lpt_dei=mphi_lpt*dei
gen mphi_opt_dei=mphi_opt*dei
gen mphi_lopt_dei=mphi_lopt*dei

*col 1: split phi into hc/lc
eststo: areg dpi dei mphi_hc_dei mphi_lc_dei mphi_hc mphi_lc mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)
test mphi_hc_dei=mphi_lc_dei

*check if the average phi_hc and phi_lc is moving by mphi bin
*first scale them by phi
gen sphi_hc=mphi_hc/mphi
gen sphi_lc=mphi_lc/mphi
tabstat sphi_hc sphi_lc, by(split_e)

*col 2: phi split high-low-other import pass-through
eststo: areg dpi dei mphi_hpt_dei mphi_lpt_dei mphi_opt_dei mphi_hpt mphi_lpt mphi_opt mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)
test mphi_hpt_dei=mphi_lpt_dei

*check if the average phi_hpt and phi_lpt is moving by mphi bin
*first scale them by phi
gen sphi_hpt=mphi_hpt/mphi
gen sphi_lpt=mphi_lpt/mphi
gen sphi_opt=mphi_opt/mphi

tabstat sphi_hpt sphi_lpt sphi_opt, by(split_e)


*col 3: add euro imports and mktsh
eststo: areg dpi dei mphi_dei mphi meuroimp_tc_dei meuroimp_tc mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)
test mphi_dei=meuroimp_tc_dei

*col 4: split phi (ie noneuro phi) into oecd and nonoecd
eststo: areg dpi dei moecd_tc_dei mnonoecd_tc_dei moecd_tc mnonoecd_tc meuroimp_tc_dei meuroimp_tc mktsh_dei mktsh yr*, cluster(ky) absorb(hs4d)
test moecd_tc_dei = mnonoecd_tc_dei


esttab using "AERrev_tables_impsource.csv", se keep(dei mphi_dei meuroimp_tc_dei moecd_tc_dei mnonoecd_tc_dei mphi_hc_dei mphi_lc_dei mphi_hpt_dei mphi_lpt_dei mphi_opt_dei mphi_lopt_dei mktsh_dei mktsh  ) b(3) se(3) r2 ar2 star(* 0.10 ** 0.05 *** 0.01) order(dei mphi_dei meuroimp_tc_dei moecd_tc_dei mnonoecd_tc_dei mphi_hc_dei mphi_lc_dei mphi_hpt_dei mphi_lpt_dei mphi_opt_dei mphi_lopt_dei mktsh_dei mktsh ) compress replace
eststo clear
drop _all


log close
