/*************************************************************************************************************************************************

					Generating new variables at the product-destination level from raw variables in the trade datasets.

***************************************************************************************************************************************************/

clear
set more off
set mem 12g
cap log close


* MAKING FILES IN WIDE FORMAT 

forval t = 1995/2008 {

	use ../rawdata/bfpixd_`t', clear
	
	*selecting transactions involving changes in changes in ownership: note that transactions coded 1 always refer to intra EU transactions, from 
	* intrastat inquire and this is from 1998 onwards
	* note that transactions coded 11 for 99% refer to extra EU transactions, from customs data
	* note that for about one percent of the observations we have intra-EU trade that is also coded with 11, the coding 11 originates from the customs data
	* for a small fraction we have observations with both codes 1 and codes 11 for the same product, country, vat.
	* we drop the transactions coded 11 if they refer to intra EU transactions
	
	keep if nature == "1" | nature == "11" 
	gen drop=1 if nature=="11" & (flow=="II" | flow=="XI") & year>=1998
	replace drop=0 if drop==.
	drop if drop==1
	drop drop
				
	save trade_yfpct_`t'.dta, replace
}

*** CORRECTION FOR DOUBLE REPORTING OF THE NEW EU COUNTRIES IN 2004 ****

* Note in 2004 the trade data for the new accession countries are reported using two lines: 
* up to May 2004 the trade flow is reported as XE & IE, From June 2004 it is XI & II***
* Since we will use unit values, it is sufficient to keep one line and use the unit value that emerges from that (this would refer to the first 6 months)

	use trade_yfpct_2004
	gen str newflow="X" if flow=="XE" | flow=="XI"
	replace newflow="I" if flow=="IE" | flow=="II"
	duplicates tag vat code land newflow,gen(tag)
	tab tag
	tab nature if tag==1
* note that of the duplicate observations there are 16,226 observations with nature==11 (extra EU) and 16,266 observations with nature = 1,
* this is what we would expect if indeed reporting of the first 6 months refers to extra EU and the last to intra EU

	egen newvalue=sum(value),by(vat code land newflow)
	egen newweight=sum(weight),by(vat code land newflow)

* keeping one line per vat code land and forcing flow to be intra EU for the full year

	drop if nature=="11" & tag==1
	replace value=newvalue if tag==1
	replace weight=newweight if tag==1
	drop tag newvalue newweight newflow

save trade_yfpct_2004,replace

****** CREATING PANEL DATA SET ********

	use trade_yfpct_1995

	forval t = 1996/2008 {

		append using trade_yfpct_`t'.dta

}
	label variable vat "VAT number"
	label variable year "Year"
	label variable land "Country of destination or origin"
	rename land cty_code
	drop nature
	compress

drop if cty_code==""
save tradepanel_annual,replace

***only keeping exports****
***************************
keep if flow=="XE"|flow=="XI"	
drop if year<1997
save exports_allyears_annual, replace	

drop if value==0
keep vat
duplicates drop
sort vat
save vat_exporters, replace


***only keeping imports****
***************************
use tradepanel_annual
keep if flow=="IE"|flow=="II"		
drop if year<1997
save imports_allyears_annual, replace	



forval t = 1995/2008 {

	capture erase trade_yfpct_`t'.dta

}

