set more 1
clear
set mem 25g

capture log using "input shares v12.log", replace
***************************************************
**** constructing import shares ****
****************************************************
*need to take out imports of final goods. There are about 10% of the observations where imports as a share of total material cost is greater than 1. Use three approaches to deal with this. One, just replace those shares to make them equal 1. Two, use BEC codes, based on Kei-Mu's JIE paper to determine which imports are inputs. Three, use io tables to determine what is an input for that industry

*first getting euro dummy to construct phi_euro
use xr_annual
keep year cty_code euro_dum
drop if euro_dum==.
sort cty_code year
save euro_dummy, replace

*1. use io_tables to determine what is an import
****************************************************
use ../rawdata/hs_iotable1705_update 
gen value=value_dom+value_imp
drop if value==0
drop if value==.
keep using_hs input_hs
destring using_hs, replace
destring input_hs, replace
sort using_hs input_hs
save temp_io, replace

use exports_allyears_annual
destring code, replace
gen hs6=int(code/100)
collapse (sum) value, by (year hs6 vat)
rename hs6 using_hs
drop value
save temp_exports, replace

use imports_allyears_annual
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2
replace euro_dum=0 if euro_dum==.
destring code, replace
gen hs6=int(code/100)
rename value imports
collapse (sum) imports, by (year hs6 vat euro_dum)
reshape wide imports, i(year vat hs6) j(euro_dum)
replace imports0=0 if imports0==.
replace imports1=0 if imports1==.
rename hs6 input_hs
save temp_imports, replace

foreach yr of numlist 1998/2008 {
use temp_exports
keep if year==`yr'
save temp_exports`yr', replace

use temp_imports
keep if year==`yr'
save temp_imports`yr', replace

}



foreach yr of numlist 1998/2008 {
use temp_imports`yr'
joinby vat using temp_exports`yr'
sort using_hs input_hs
merge using_hs input_hs using temp_io
keep if _merge==3
drop _merge
save mergedtrade`yr', replace
}

use mergedtrade1998
foreach yr of numlist 1999/2008 {
append using mergedtrade`yr'
}

save mergedtrade_all, replace
keep year vat input_hs imports* 
duplicates drop
collapse (sum) imports*, by(vat year)
gen totimports=imports0+imports1
rename imports0 noneuroimports
sort vat year
merge vat year using mc_firm
tab _merge
drop if _merge==2
drop _merge

*ensuring that imports are not greater than matcost
gen over_io=totimports>matcost
gen impshare_io=totimports/matcost
gen imp_tc_io=totimports/totcost
gen noneuroimp_tc_io=noneuroimports/totcost
keep year vat impshare_io imp_tc_io imp_tc_io noneuroimp_tc_io over*
sort vat year
save mergedtrade_all_io, replace


*********************************************
*ii: include all imports

use exports_allyears_annual
keep vat
duplicates drop
sort vat
save vat_exporters, replace

use imports_allyears_annual
*only keep exporters
*10% of imports do not export
sort vat
merge vat using vat_exporters
tab _merge
keep if _merge==3
drop _merge
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2
replace euro_dum=0 if euro_dum==.
collapse (sum) value, by(vat year euro_dum)
reshape wide value, i(year vat) j(euro_dum)
replace value0=0 if value0==.
replace value1=0 if value1==.
gen totimports=value0+value1
gen noneuroimports=value0
sort vat year
merge vat year using mc_firm
drop if year>2008
tab _merge
drop if _merge==2
drop _merge
gen over=totimports>matcost
gen impshare=totimports/matcost
gen imp_tc=totimports/totcost
gen noneuroimp_tc=noneuroimports/totcost
sum impshare, detail
sort vat year
save temp_impshare, replace


*iii: dropping consumer goods
***************
clear
insheet using "../rawdata/concordance hs6 to bec.CSV"
rename productcode hs6 
rename becproductcode bec
keep hs6 bec
gen consumer_goods =1 if inlist(bec, 112, 122, 51, 522, 61, 62, 63 )
gen capital_goods=1 if bec==41
*dropping nec
drop if bec==7
sort hs6
save bec_codes, replace


use imports_allyears_annual
destring code, replace
gen hs6=int(code/100)
sort hs6
merge hs6 using bec_codes
tab _merge
*only 1% of the hs6 codes could not be matched to bec_code. We used hs_combined to bec, can try hs6.
*40% of observations and 20% of the value are consumption_goods
drop if consumer_goods==1
drop consumer_goods capital_goods _merge
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2
replace euro_dum=0 if euro_dum==.
collapse (sum) value, by(vat year euro_dum)
reshape wide value, i(year vat) j(euro_dum)
replace value0=0 if value0==.
replace value1=0 if value1==.
gen totimports=value0+value1
gen noneuroimports=value0

sort vat year
merge vat year using mc_firm
drop if year>2008
tab _merge
drop if _merge==2
drop _merge
*only affects less than 1% of observations
gen over_bec=totimports>matcost
gen impshare_bec=totimports/matcost
gen imp_tc_bec=totimports/totcost
gen noneuroimp_tc_bec=noneuroimports/totcost

drop matcost totcost value* noneuroimports
sort vat year
save matcost_share_con, replace


*iv: dropping capital goods
***************
use imports_allyears_annual
destring code, replace
gen hs6=int(code/100)
sort hs6
merge hs6 using bec_codes
tab _merge
*only 1% of the hs6 codes could not be matched to bec_code. We used hs_combined to bec, can try hs6.
*40% of observations and 20% of the value are consumption_goods
drop if capital_goods==1
drop consumer_goods capital_goods _merge
sort cty_code year
merge cty_code year using euro_dummy
tab _merge
drop if _merge==2
replace euro_dum=0 if euro_dum==.
collapse (sum) value, by(vat year euro_dum)
reshape wide value, i(year vat) j(euro_dum)
replace value0=0 if value0==.
replace value1=0 if value1==.
gen totimports=value0+value1
gen noneuroimports=value0

sort vat year
merge vat year using mc_firm
drop if year>2008
tab _merge
drop if _merge==2
drop _merge
*only affects less than 1% of observations
gen over_cap=totimports>matcost
gen impshare_cap=totimports/matcost
gen imp_tc_cap=totimports/totcost
gen noneuroimp_tc_cap=noneuroimports/totcost

keep year vat noneuroimp_tc_cap over
sort vat year
save matcost_share_cap, replace


clear
*merging all files
use matcost_share_cap
sort vat year
merge vat year using matcost_share_con
drop _merge
sort vat year
merge vat year using temp_impshare
tab _merge
drop _merge
sort vat year
merge vat year using mergedtrade_all_io
tab _merge
keep year vat imp* non* over*
sort vat year
save matcost_share, replace


*erase temp files
foreach yr of numlist 1998/2008 {
erase temp_exports`yr'.dta
erase temp_imports`yr'.dta
erase mergedtrade`yr'.dta
}


erase temp_impshare.dta
erase temp_imports.dta
erase temp_exports.dta
erase mergedtrade_all.dta
erase temp_io.dta


